<?php

    // render category filter 
    if( !function_exists('glgu_category_filter_render_callback') ){
        function glgu_category_filter_render_callback( $atts, $content ){
            global $glgu_cat, $glgu_section, $glgu_post_type;

            // initialize
            if( !isset($atts['style']) ) $atts['style'] = 'dot-top';
            if( !isset($atts['align']) ) $atts['align'] = 'left';
            if( !isset($atts['sectionId']) ) $atts['sectionId'] = '';
            if( !isset($atts['postType']) ) $atts['postType'] = 'product';
            if( !isset($atts['withAll']) ) $atts['withAll'] = true;

            if( $atts['postType'] == 'product' ){
                $cat_list = glgu_get_term_list('product_cat');
            }else if( $atts['postType'] == 'post' ){
                $cat_list = glgu_get_term_list('category');
            }

            $extra_class  = ' glgu-style-' . $atts['style'];
            $extra_class .= ' has-text-align-' . $atts['align'];

            $extra_css  = '';
            $extra_css .= empty($atts['gap'])? '': ' gap:' . $atts['gap'] . ';';
            $extra_css .= empty($atts['fontSize'])? '': ' font-size:' . $atts['fontSize'] . ';';
            $extra_css .= empty($atts['color'])? '': ' --category-filter-text:' . $atts['color'] . ';';
            $extra_css .= empty($atts['activeColor'])? '': ' --category-filter-text-active:' . $atts['activeColor'] . ';';
            $extra_css .= empty($atts['indicatorColor'])? '': ' --category-filter-text-indicator:' . $atts['indicatorColor'] . ';';

            $active_cat = '';
            if( !empty($glgu_section) && $glgu_section == $atts['sectionId'] && 
                !empty($glgu_post_type) && $glgu_post_type == $atts['postType'] && !empty($glgu_cat) ){
                 
                $active_cat = sanitize_key($glgu_cat);
            }

            // print item
            $ret  = '<div class="glgu-category-filter ' . esc_attr($extra_class) . '" ';
            $ret .= 'data-post-type="' . esc_attr($atts['postType']) . '" ';
            $ret .= 'data-section-id="' . esc_attr($atts['sectionId']) . '" ';
            $ret .= empty($extra_css)? '': 'style="' . esc_attr($extra_css) . '" ';
            $ret .= ' >';
            if( !empty($atts['withAll']) ){
                $ret .= '<span data-cat="all" ';
                if( empty($active_cat) || $active_cat == 'all' ){
                    $ret .= ' class="glgu-active" ';
                    $active_cat = 'all';
                }
                $ret .= ' >' . esc_html__('All', 'goodlayers-blocks') . '</span>';
            }
            if( !empty($atts['categories']) ){
                foreach($atts['categories'] as $cat){
                    if( empty($cat_list[$cat]) ) continue;
                    $ret .= '<span data-cat="' . esc_attr($cat) . '" ';
                    $ret .= ($cat == $active_cat)? ' class="glgu-active" ': '';
                    $ret .= '>' . esc_html($cat_list[$cat]) . '</span>';
                }
            }
            $ret .= '<span class="glgu-slide-bar" ></span>';
            $ret .= '</div>';
            return $ret;
        }
    }

    // ajax content render
    add_action('init', 'glgu_category_filter_ajax');
    if( !function_exists('glgu_category_filter_ajax') ){
        function glgu_category_filter_ajax(){
            global $glgu_cat, $glgu_section, $glgu_post_type;

            if( !empty($_GET['glguCat']) && !empty($_GET['glguSection']) && !empty($_GET['glguPostType']) ){

                // verify nonce
                if( isset($_GET['security']) ){
                    $nonce = sanitize_text_field(wp_unslash($_GET['security']));
                    if( !wp_verify_nonce($nonce, 'glgu_nonce') ){
                        die();
                    }
                }else{
                    die();
                }

                $glgu_cat = sanitize_text_field(wp_unslash($_GET['glguCat']));
                $glgu_section = sanitize_text_field(wp_unslash($_GET['glguSection']));
                $glgu_post_type = sanitize_text_field(wp_unslash($_GET['glguPostType']));
                
                // get data
                add_filter('render_block_data', 'glgu_category_filter_block_full', 20, 3);
            }
        }
    }
    
    if( !function_exists('glgu_category_filter_block_full') ){
        function glgu_category_filter_block_full($parsed_block, $source_block, $parent_block){
            global $glgu_cat, $glgu_section, $glgu_post_type;

            // search for block with id = section_id
            $search_id = empty($glgu_section)? '': 'id="' . esc_attr(sanitize_key($glgu_section)) . '"';
            if( strpos($parsed_block['innerHTML'], $search_id) !== false ){
                $target_block = $parsed_block;
            }
            
            if( !empty($target_block) ){
                remove_filter('render_block_data', 'glgu_category_filter_block_update', 20);

                $categories = array();
                if( !empty($glgu_post_type) && $glgu_post_type == 'product' ){
                    if( !empty($glgu_cat) && $glgu_cat != 'all' ){
                        $term = get_term_by('slug', sanitize_key($glgu_cat), 'product_cat');
                        if( !empty($term) ){
                            $categories[] = $term->term_id;
                        }

                        $parsed_block = glgu_rewrite_block_attributes($target_block, 'woocommerce/product-category', 'categories', $categories);
                    }
            
                }else if( !empty($glgu_post_type) && $glgu_post_type == 'post' ){

                }
            }
            
            return $parsed_block;
        
        }
    }

    if( !function_exists('glgu_rewrite_block_attributes') ){
        function glgu_rewrite_block_attributes($blocks, $block_name, $attr_slug, $attr_value){
            
            // parent element
            if( !empty($blocks['blockName']) ){
                if( $blocks['blockName'] == $block_name ){
                    $blocks['attrs'][$attr_slug] = $attr_value;
                }

                if( !empty($blocks['innerBlocks']) ){
                    $blocks['innerBlocks'] = glgu_rewrite_block_attributes($blocks['innerBlocks'], $block_name, $attr_slug, $attr_value);
                }

            // child element
            }else{
                foreach($blocks as $block_slug => $block){
                    if( $block['blockName'] == $block_name ){
                        $blocks[$block_slug]['attrs'][$attr_slug] = $attr_value;
                    }
    
                    if( !empty($block['innerBlocks']) ){
                        $blocks[$block_slug]['innerBlocks'] = glgu_rewrite_block_attributes($block['innerBlocks'], $block_name, $attr_slug, $attr_value);
                    }
                }
            }

            return $blocks;
        }
    }


    // category filter script
    add_action('wp_footer', 'glgu_footer_category_filter_script');
    if( !function_exists('glgu_footer_category_filter_script') ){
        function glgu_footer_category_filter_script(){
?><script>
(function($){
    $(document).ready(function(){
        
        // category filter
        $('.glgu-category-filter').each(function(){
            var item = $(this);

            // slidebar position
            var slidebar = item.children('.glgu-slide-bar');
            var slidebar_pos = {};
            
            item.children('.glgu-active').each(function(){
                slidebar_pos.left = $(this).position().left;
                slidebar_pos.width = $(this).outerWidth();
            });
            slidebar.css(slidebar_pos).fadeIn(200);
            
            // slidebar hover
            item.children('[data-cat]').on('mouseenter', function(){
                slidebar.animate({
                    left: $(this).position().left,
                    width: $(this).outerWidth()
                }, {duration: 200, queue: false});
            }).on('click', function(){
                slidebar_pos = {
                    left: $(this).position().left,
                    width: $(this).outerWidth()
                };
                slidebar.css(slidebar_pos, {duration: 200, queue: false});
            });
            item.on('mouseleave', function(){
                slidebar.animate(slidebar_pos, {duration: 200, queue: false});
            });

            // ajax filter
            var post_type = item.attr('data-post-type');
            var section_id = item.attr('data-section-id');
            var url = window.location.href;
            
            item.on('click', '[data-cat]', function(){
                var cat = $(this).attr('data-cat');

                var now_loading = $('<div class="glgu-now-loading" ></div>');
                now_loading.appendTo($('body')).fadeIn(300);

                $.ajax({
                    url: url,
                    data: {
                        glguCat: cat, 
                        glguSection: section_id, 
                        glguPostType: post_type,
                        security: '<?php echo esc_js(wp_create_nonce("glgu_nonce")); ?>'
                    },
                    method: 'GET',
                    dataType: 'text',
                    error: function(a, b, c){
                        console.log(a, b, c);
                    },
                    success: function(data){
                        
                        // replace block suppor css
                        var inline_start = data.indexOf('<style id=\'core-block-supports-inline-css\'>') + 43;
                        var inline_end = data.indexOf('</style>', inline_start);
                        var inline = data.substr(inline_start, inline_end - inline_start);
                        $('html head').find('#core-block-supports-inline-css').html(inline);

                        // replace body content
                        var body_start = data.indexOf('>', data.indexOf('<body')) + 1;
                        var body_end = data.lastIndexOf('</body>');
                        var body = data.substr(body_start, body_end - body_start);
                        $('html body').html(body).css({opacity: 0}).delay(300).animate({opacity: 1}, {duration: 300});
                    }
                })
            });
        });

    });
})(jQuery);
</script><?php
        }
    }