<?php
/**
 * Plugin Name:       Goodlayers Blocks
 * Plugin URI:        https://wordpress.org/plugins/
 * Description:       Extra useful elements for theme styling
 * Version:           1.0.3
 * Author:            Goodlayers
 * Author URI:        https://goodlayers.com/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       goodlayers-blocks
 */

    // define necessary variable for the site.
	define('GLGU_URL', plugins_url('', __FILE__));
	define('GLGU_LOCAL', dirname(__FILE__));

    include_once(GLGU_LOCAL . '/util.php');
    include_once(GLGU_LOCAL . '/category-filter.php');
    include_once(GLGU_LOCAL . '/product-category.php');

    add_action('init', 'glgu_register_block');
    if( !function_exists('glgu_register_block') ){
        function glgu_register_block(){

            /* accordion */
            $block_accordion_asset = include(GLGU_LOCAL . '/js/dist/accordion.asset.php');
            wp_register_script('glgu-accordion', GLGU_URL . '/js/dist/accordion.js', $block_accordion_asset['dependencies'], $block_accordion_asset['version'], true);
            register_block_type('glgu/accordion', array(
                'editor_script' => 'glgu-accordion'
            ));

            /* rating */
            $block_rating_asset = include(GLGU_LOCAL . '/js/dist/rating.asset.php');
            wp_register_script('glgu-rating', GLGU_URL . '/js/dist/rating.js', $block_rating_asset['dependencies'], $block_rating_asset['version'], true);
            register_block_type('glgu/rating', array(
                'editor_script' => 'glgu-rating'
            ));

            // slider controls
            $slider_controls_asset = include(GLGU_LOCAL . '/js/dist/slider-controls.asset.php');
            wp_register_script('glgu-slider-controls', GLGU_URL . '/js/dist/slider-controls.js', $slider_controls_asset['dependencies'], $slider_controls_asset['version'], true);
            register_block_type('glgu/slider-controls', array(
                'editor_script' => 'glgu-slider-controls'
            ));

            /* group custom */
            $group_custom_asset = include(GLGU_LOCAL . '/js/dist/group-custom.asset.php');
            wp_register_script('glgu-group-custom', GLGU_URL . '/js/dist/group-custom.js', $group_custom_asset['dependencies'], $group_custom_asset['version'], true);
            wp_localize_script('glgu-group-custom', 'glguGroupCustom', array(
                'enableCarousel' => get_theme_support('glgu-group-custom-carousel'),
            ));
            register_block_type('glgu/group-custom', array(
                'editor_script' => 'glgu-group-custom'
            ));

            // fa social
            $fa_social_asset = include(GLGU_LOCAL . '/js/dist/fa-social.asset.php');
            wp_register_script('glgu-fa-social', GLGU_URL . '/js/dist/fa-social.js', $fa_social_asset['dependencies'], $fa_social_asset['version'], true);
            register_block_type('glgu/fa-social', array(
                'editor_script' => 'glgu-fa-social'
            ));

            // shape divider
            $shape_divider = include(GLGU_LOCAL . '/js/dist/shape-divider.asset.php');
            wp_register_script('glgu-shape-divider', GLGU_URL . '/js/dist/shape-divider.js', $shape_divider['dependencies'], $shape_divider['version'], true);
            register_block_type('glgu/shape-divider', array(
                'editor_script' => 'glgu-shape-divider'
            ));

            // category filter
            $category_filter = include(GLGU_LOCAL . '/js/dist/category-filter.asset.php');
            wp_register_script('glgu-category-filter', GLGU_URL . '/js/dist/category-filter.js', $category_filter['dependencies'], $category_filter['version'], true);
            wp_localize_script('glgu-category-filter', 'GLGU_CAT', array(
                'all' => esc_html__('All', 'goodlayers-blocks'),
                'product' => glgu_get_term_list('product_cat'),
                'post' => glgu_get_term_list('category')
            ));
            register_block_type('glgu/category-filter', array(
                'editor_script' => 'glgu-category-filter',
                'render_callback' => 'glgu_category_filter_render_callback'
            ));

            /* product-category */
            $product_category_asset = include(GLGU_LOCAL . '/js/dist/product-category.asset.php');
            wp_register_script('glgu-product-category', GLGU_URL . '/js/dist/product-category.js', $product_category_asset['dependencies'], $product_category_asset['version'], true);
            wp_localize_script('glgu-product-category', 'GLGU_THUMBNAIL', glgu_get_thumbnail_sizes());
            register_block_type('glgu/product-category', array(
                'editor_script' => 'glgu-product-category',
                'render_callback' => 'glgu_product_category_callback', 
                'attributes' => array(
                    'categories' => array(
                        'type'    => 'array',
                        'default' => array(),
                    ),
                    'thumbnailSize' => array(
                        'type'    => 'string',
                        'default' => 'full'
                    ),
                    'column' => array(
                        'type'    => 'string',
                        'default' => '3',
                    ),
                    'columnGap' => array(
                        'type'    => 'string',
                        'default' => '',
                    ),
                    'align' => array(
                        'type'    => 'string',
                        'default' => 'left',
                    )
                )
            ));
        }
    }

    add_action('after_setup_theme', 'glgu_editor_style');
    if( !function_exists('glgu_editor_style') ){
        function glgu_editor_style(){
            add_editor_style(GLGU_URL . '/editor-style.css');
        }
    }
    add_action('wp_head', 'glgu_head_style');
    if( !function_exists('glgu_head_style') ){
        function glgu_head_style(){
?><style>
.glgu-now-loading{ display: none; position: fixed; top: 0px; right: 0px; bottom: 0px; left: 0px; background: #fff; z-index: 9999; opacity: 0.8; }

.glgu-column{ display: flex; flex-wrap: wrap; gap: var(--theme--spacing--gap); }
.glgu-column-1 > div{ width: 100%; } 
.glgu-column-2 > div{ width:calc(50% - (var(--theme--spacing--gap)/2)); }
.glgu-column-3 > div{ width:calc(33.33333% - (var(--theme--spacing--gap)*2/3)); }
.glgu-column-4 > div{ width:calc(25% - (var(--theme--spacing--gap)*3/4)); }
.glgu-column-5 > div{ width:calc(20% - (var(--theme--spacing--gap)*4/5)); }
.glgu-column-6 > div{ width:calc(16.66667% - (var(--theme--spacing--gap)*5/6)); }

@media only screen and (max-width: 999px) {
    .glgu-column-4 > div, 
    .glgu-column-5 > div, 
    .glgu-column-6 > div{ width:calc(33.33333% - (var(--theme--spacing--gap)*2/3)); }
    .glgu-column-3 > div{ width: calc(50% - (var(--theme--spacing--gap)/2)); }
}
@media only screen and (max-width: 768px) {
    .glgu-column-3 > div, 
    .glgu-column-4 > div, 
    .glgu-column-5 > div, 
    .glgu-column-6 > div{ width:calc(50% - (var(--theme--spacing--gap)/2)); }
    .glgu-column-2 > div{ width: 100%; max-width: 400px; }
}
@media only screen and (max-width: 550px) {
    .glgu-column-2 > div, 
    .glgu-column-3 > div, 
    .glgu-column-4 > div, 
    .glgu-column-5 > div, 
    .glgu-column-6 > div{ width:calc(50% - (var(--theme--spacing--gap)/2)); }
}

.glgu-rating{ color: #ffc200; }
.glgu-group-custom{ box-sizing: border-box; margin-left: auto; margin-right: auto; background-size: cover; background-position: center; background-repeat: no-repeat; }

/* carousel bullet */
ul.glgu-bullet li{ background: var(--slider-controls-bg, #d6dae8); }
ul.glgu-bullet li.active{ background: var(--slider-controls-bg-active, #516bc4); }
ul.glgu-bullet{ list-style: none; margin: 0px; padding: 0px; white-space: nowrap; }
ul.glgu-bullet-style-1 li{ display: inline-block; width: 8px; height: 8px; margin-left: 10px; 
    cursor: pointer; overflow: hidden; transition: background 300ms;
    -webkit-border-radius: 50%; -moz-border-radius: 50%; border-radius: 50%; }
ul.glgu-bullet-style-1 li:first-child{ margin-left: 0px; }

/* accordion */
.glgu-accordion-tab{ padding: 30px 0px; border-top-width: 1px; border-top-style: solid; }
.glgu-accordion-tab:first-child{ border-top: 0px; padding-top: 0px; }
.glgu-accordion-tab .glgu-accordion-tab-content{ padding: 0px 30px; transition: padding 200ms, box-shadow 200ms; }
.glgu-accordion-tab .glgu-accordion-title{ margin-bottom: 0px; font-size: 18px; cursor: pointer; }
.glgu-accordion-tab .glgu-accordion-title:after{ content: "\f543"; font-family: "dashicons"; float: right; transition: opacity 200ms; }
.glgu-accordion-tab .glgu-accordion-content{ padding-top: 20px; display: none; }
.glgu-accordion-tab.glgu-active .glgu-accordion-content{ display: block; }
.glgu-accordion-tab.glgu-active .glgu-accordion-tab-content{ padding: 28px 30px; box-shadow: 0 20px 40px rgba(0,0,0,0.1); }
.glgu-accordion-tab.glgu-active .glgu-accordion-title:after{ content: "\f460"; opacity: 0.6; }

/* fa social */
.glgu-fa-social{ display: flex; flex-direction: row; font-size: 25px; gap: 30px; }
.glgu-fa-social a{ flex-shrink: 0; text-align: center; width: var(--fa-social--width); line-height: var(--fa-social--width);
    border-style: solid; border-width: var(--fa-social--frame-width, 0px); border-radius: var(--fa-social--radius); 
    color: var(--fa-social--icon-color); border-color: var(--fa-social--border-color); }
.glgu-fa-social a:hover{ color: var(--fa-social--icon-hover-color); }
.glgu-fa-social.has-text-align-center{ justify-content: center; }
.glgu-fa-social.has-text-align-right{ justify-content: flex-end; }

/* shape divider */
.glgu-shape-divider{ overflow: hidden; }
.glgu-shape-divider svg path{ fill: var(--shape-divider-color); opacity: var(--shape-divider-opacity); }
.glgu-shape-divider svg{ width: var(--shape-divider-width, 100%); height: var(--shape-divider-height); }
.glgu-shape-divider-wrap{ line-height: 0; }
.glgu-shape-divider-wrap svg{ left: 50%; position: relative;
    -webkit-transform: translateX(-50%); -moz-transform: translateX(-50%); transform: translateX(-50%); }
.glgu-shape-divider.glgu-bottom .glgu-shape-divider-wrap,
.glgu-shape-divider.glgu-invert.glgu-top .glgu-shape-divider-wrap{ -webkit-transform: rotate(180deg); -moz-transform: rotate(180deg); transform: rotate(180deg); }
.glgu-shape-divider.glgu-invert.glgu-bottom .glgu-shape-divider-wrap{ -webkit-transform: rotate(0deg); -moz-transform: rotate(0deg); transform: rotate(0deg); }

/* shape divider front end */
.glgu-shape-divider{ position: absolute; left: 0; right: 0; }
.glgu-shape-divider.glgu-top{ top: 0; }
.glgu-shape-divider.glgu-bottom{ bottom: 0; }
.glgu-shape-divider.glgu-hide-desktop{ display: none; }
.glgu-shape-divider.glgu-hide-desktop-tablet{ display: none; }
@media only screen and (max-width: 999px){
    .glgu-shape-divider.glgu-hide-desktop{ display: block; }
    .glgu-shape-divider.glgu-hide-tablet{ display: none; }
    .glgu-shape-divider.glgu-hide-tablet-mobile{ display: none; }
}
@media only screen and (max-width: 767px){
    .glgu-shape-divider.glgu-hide-desktop-tablet{ display: block; }
    .glgu-shape-divider.glgu-hide-tablet{ display: block; }
    .glgu-shape-divider.glgu-hide-mobile{ display: none; }
}

/* category filter */
.glgu-category-filter{ position: relative; display: flex; gap: 25px; font-weight: 600; }
.glgu-category-filter.has-text-align-left{ justify-content: flex-start; }
.glgu-category-filter.has-text-align-right{ justify-content: flex-end; }
.glgu-category-filter.has-text-align-center{ justify-content: center; }
.glgu-category-filter span{ cursor: pointer; color: var(--category-filter-text, #888); }
.glgu-category-filter span.glgu-active{ cursor: pointer; color: var(--category-filter-text-active, #000); }
.glgu-category-filter .glgu-slide-bar{ display: none; position: absolute; }
.glgu-category-filter.glgu-style-dot-top .glgu-slide-bar{ top: -12px; }
.glgu-category-filter.glgu-style-dot-top .glgu-slide-bar:before{ content: " "; display: block; width: 6px; height: 6px; margin: 0px auto; 
    background: var(--category-filter-text-indicator, #000);
    -webkit-border-radius: 50%; -moz-border-radius: 50%; border-radius: 50%; }
@media only screen and (max-width: 768px){
    .glgu-category-filter{ flex-wrap: wrap; }
    .glgu-category-filter .glgu-slide-bar{ display: none; }
}

/* product category */
.glgu-product-category-wrap .glgu-thumbnail{ line-height:0; margin-bottom: 10px; }
.glgu-product-category-wrap .glgu-title{ font-size: 18px; }

</style><?php
        }
    }
 
    add_filter('pre_render_block', 'glgu_pre_render_block_styles', 10, 2);
    if( !function_exists('glgu_pre_render_block_styles') ){
        function glgu_pre_render_block_styles($pre_render, $block){
            if( $block['blockName'] == 'glgu/group-custom' ){
                $css  = '';

                if( isset($block['attrs']['id']) ){
                    $id = 'glgu-group-custom-' . $block['attrs']['id'];

                    $tabletCss = '';
                    if( !empty($block['attrs']['tabletPadding']) ){ 
                        $tabletCss .= box_control_css('padding', $block['attrs']['tabletPadding']);
                    }
                    if( !empty($block['attrs']['tabletMargin']) ){
                        $tabletCss .= box_control_css('margin', $block['attrs']['tabletMargin']);
                    }
                    if( !empty($block['attrs']['tabletBackgroundImage']) ){
                        $tabletCss .= 'background-image: url("' . esc_url($block['attrs']['tabletBackgroundImage']) . '") !important;';
                    }
                    
                    if( !empty($tabletCss) ){
                        $css .= "@media only screen and (max-width: 999px){ #{$id}{{$tabletCss}} }";
                    }

                    $mobileCss = '';
                    if( !empty($block['attrs']['mobilePadding']) ){
                        $mobileCss .= box_control_css('padding', $block['attrs']['mobilePadding']);
                    }
                    if( !empty($block['attrs']['mobileMargin']) ){
                        $mobileCss .= box_control_css('margin', $block['attrs']['mobileMargin']);
                    }
                    if( !empty($block['attrs']['mobileBackgroundImage']) ){
                        $mobileCss .= 'background-image: url("' . esc_url($block['attrs']['mobileBackgroundImage']) . '") !important;';
                    }
                    if( !empty($mobileCss) ){
                        $css .= "@media only screen and (max-width: 767px){ #{$id}{{$mobileCss}} }";
                    }
                }

                if( !empty($css) ){
                    wp_enqueue_block_support_styles($css);
                }

            }
            return $pre_render;
        }
    }

    add_action('wp_footer', 'glgu_footer_script');
    if( !function_exists('glgu_footer_script') ){
        function glgu_footer_script(){
?><script>
(function($){
    $(document).ready(function(){
        
        // accordion
        $('.glgu-accordion-item').each(function(){
            
            var t = $(this);
            var isToggleBox = ($(this).attr('data-type') == 'toggle-box');

            t.find('.glgu-accordion-title').on('click', function(){

                var parent = $(this).closest('.glgu-accordion-tab');
                if( parent.hasClass('glgu-active') ){
                    parent.removeClass('glgu-active');
                }else{
                    parent.addClass('glgu-active');
                    if( !isToggleBox ){
                        parent.siblings().removeClass('glgu-active');
                    }
                }

            });
        
        });

    });
})(jQuery);
</script><?php
        }
    }

    // get all thumbnail name
	if( !function_exists('glgu_get_thumbnail_sizes') ){
		function glgu_get_thumbnail_sizes(){
			$ret = array(
                array(
                    'value' => 'full', 
                    'label' => esc_html__('full size', 'goodlayers-blocks')

                )
            );
			
			$thumbnails = get_intermediate_image_sizes();
			foreach( $thumbnails as $thumbnail ) {
				if( !empty($GLOBALS['_wp_additional_image_sizes'][$thumbnail]) ){
					$width = $GLOBALS['_wp_additional_image_sizes'][$thumbnail]['width'];
					$height = $GLOBALS['_wp_additional_image_sizes'][$thumbnail]['height'];
				}else{
					$width = get_option($thumbnail . '_size_w', '');
					$height = get_option($thumbnail . '_size_h', '');
				}

                $temp = array(
                    'value' => $thumbnail,
                    'label' => $thumbnail . ' ' . $width . '-' . $height
                );
                $ret[] = $temp;
			}
			return $ret;
		}
	}